@@ -171,7 +171,7 @@ autoconf_2_52d_check ()
   # autoconf 2.52d has a weird issue involving a yes:no error
   # so don't allow it's use
   test -z "$NOCHECK" && {
-    ac_version=`$autoconf --version|head -n 1|sed 's/^[a-zA-z\.\ ()]*//;s/ .*$//'`
+    ac_version=`$autoconf --version|head -n 1|sed 's/^[a-zA-Z\.\ ()]*//;s/ .*$//'`
     if test "$ac_version" = "2.52d"; then
       echo "autoconf 2.52d has an issue with our current build."
       echo "We don't know who's to blame however.  So until we do, get a"
@@ -198,7 +198,7 @@ die_check ()
 
 autogen_options ()
 {
-  if test "x$1" == "x"; then
+  if test "x$1" = "x"; then
     return 0
   fi
 
@@ -262,6 +262,11 @@ autogen_options ()
 	  CONFIGURE_DEF_OPT="$CONFIGURE_DEF_OPT --with-autoconf=$AUTOCONF"
           shift
           ;;
+      --disable*|--enable*|--with*)
+          echo "+ passing option $1 to configure"
+	  CONFIGURE_EXT_OPT="$CONFIGURE_EXT_OPT $1"
+          shift
+          ;;
        --) shift ; break ;;
       *) echo "- ignoring unknown autogen.sh argument $1"; shift ;;
     esac
