@@ -26,18 +26,15 @@
 
 #include "gstaggregator.h"
 
-GST_DEBUG_CATEGORY (gst_aggregator_debug);
+GST_DEBUG_CATEGORY_STATIC (gst_aggregator_debug);
 #define GST_CAT_DEFAULT gst_aggregator_debug
 
-GstElementDetails gst_aggregator_details = {
+GstElementDetails gst_aggregator_details = GST_ELEMENT_DETAILS (
   "Aggregator pipe fitting",
   "Generic",
-  "LGPL",
   "N-to-1 pipe fitting",
-  VERSION,
-  "Wim Taymans <wim.taymans@chello.be>",
-  "(C) 2001",
-};
+  "Wim Taymans <wim.taymans@chello.be>"
+);
 
 /* Aggregator signals and args */
 enum {
@@ -54,11 +51,11 @@ enum {
   /* FILL ME */
 };
 
-GST_PAD_TEMPLATE_FACTORY (aggregator_src_factory,
+GstStaticPadTemplate aggregator_src_template = GST_STATIC_PAD_TEMPLATE (
   "sink%d",
   GST_PAD_SINK,
   GST_PAD_REQUEST,
-  GST_CAPS_ANY
+  GST_STATIC_CAPS_ANY
 );
 
 #define GST_TYPE_AGGREGATOR_SCHED (gst_aggregator_sched_get_type())
@@ -80,9 +77,6 @@ gst_aggregator_sched_get_type (void)
 
 #define AGGREGATOR_IS_LOOP_BASED(ag)	((ag)->sched != AGGREGATOR_CHAIN)
 
-static void 	gst_aggregator_class_init	(GstAggregatorClass *klass);
-static void 	gst_aggregator_init		(GstAggregator *aggregator);
-
 static GstPad* 	gst_aggregator_request_new_pad	(GstElement *element, GstPadTemplate *temp, const
                                                  gchar *unused);
 static void 	gst_aggregator_update_functions	(GstAggregator *aggregator);
@@ -95,31 +89,19 @@ static void 	gst_aggregator_get_property 	(GObject *object, guint prop_id,
 static void  	gst_aggregator_chain 		(GstPad *pad, GstData *_data);
 static void 	gst_aggregator_loop 		(GstElement *element);
 
-static GstElementClass *parent_class = NULL;
-/*static guint gst_aggregator_signals[LAST_SIGNAL] = { 0 };*/
+#define _do_init(bla) \
+  GST_DEBUG_CATEGORY_INIT (gst_aggregator_debug, "aggregator", 0, "aggregator element");
 
-GType
-gst_aggregator_get_type (void) 
+GST_BOILERPLATE_FULL (GstAggregator, gst_aggregator, GstElement, GST_TYPE_ELEMENT, _do_init);
+
+static void
+gst_aggregator_base_init (gpointer g_class)
 {
-  static GType aggregator_type = 0;
-
-  if (!aggregator_type) {
-    static const GTypeInfo aggregator_info = {
-      sizeof(GstAggregatorClass),      
-      NULL,
-      NULL,
-      (GClassInitFunc)gst_aggregator_class_init,
-      NULL,
-      NULL,
-      sizeof(GstAggregator),
-      0,
-      (GInstanceInitFunc)gst_aggregator_init,
-    };
-    aggregator_type = g_type_register_static (GST_TYPE_ELEMENT, "GstAggregator", &aggregator_info, 0);
-  }
-  return aggregator_type;
+  GstElementClass *gstelement_class = GST_ELEMENT_CLASS (g_class); 
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&aggregator_src_template));
+  gst_element_class_set_details (gstelement_class, &gst_aggregator_details);
 }
-
 static void
 gst_aggregator_class_init (GstAggregatorClass *klass) 
 {
@@ -129,7 +111,6 @@ gst_aggregator_class_init (GstAggregatorClass *klass)
   gobject_class = (GObjectClass*) klass;
   gstelement_class = (GstElementClass*) klass;
 
-  parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_NUM_PADS,
     g_param_spec_int ("num_pads", "Num pads", "The number of source pads",
@@ -154,6 +135,7 @@ static void
 gst_aggregator_init (GstAggregator *aggregator) 
 {
   aggregator->srcpad = gst_pad_new ("src", GST_PAD_SRC);
+  gst_pad_set_getcaps_function (aggregator->srcpad, gst_pad_proxy_getcaps);
   gst_element_add_pad (GST_ELEMENT (aggregator), aggregator->srcpad);
 
   aggregator->numsinkpads = 0;
@@ -174,7 +156,7 @@ gst_aggregator_request_new_pad (GstElement *element, GstPadTemplate *templ, cons
   g_return_val_if_fail (GST_IS_AGGREGATOR (element), NULL);
 
   if (templ->direction != GST_PAD_SINK) {
-    g_warning ("gstaggregator: request new pad that is not a SRC pad\n");
+    g_warning ("gstaggregator: request new pad that is not a sink pad\n");
     return NULL;
   }
 
@@ -188,6 +170,7 @@ gst_aggregator_request_new_pad (GstElement *element, GstPadTemplate *templ, cons
   if (!AGGREGATOR_IS_LOOP_BASED (aggregator)) {
     gst_pad_set_chain_function (sinkpad, gst_aggregator_chain);
   }
+  gst_pad_set_getcaps_function (sinkpad, gst_pad_proxy_getcaps);
   gst_element_add_pad (GST_ELEMENT (aggregator), sinkpad);
   
   aggregator->sinkpads = g_list_prepend (aggregator->sinkpads, sinkpad);
@@ -327,7 +310,7 @@ gst_aggregator_loop (GstElement *element)
 
       debug = "loop_select";
 
-      pad = gst_pad_select (aggregator->sinkpads);
+      pad = gst_pad_selectv (aggregator->sinkpads);
       buf = GST_BUFFER (gst_pad_pull (pad));
 
       gst_aggregator_push (aggregator, pad, buf, debug);
@@ -360,11 +343,4 @@ gst_aggregator_chain (GstPad *pad, GstData *_data)
 
   gst_aggregator_push (aggregator, pad, buf, "chain");
 }
-
-gboolean
-gst_aggregator_factory_init (GstElementFactory *factory)
-{
-  gst_element_factory_add_pad_template (factory, GST_PAD_TEMPLATE_GET (aggregator_src_factory));
-
-  return TRUE;
-}
+  
