@@ -27,6 +27,18 @@
 #include "gstdata_private.h"
 #include "gstinfo.h"
 
+GType
+gst_data_get_type (void)
+{
+  static GType type = 0;
+  
+  if (!type)
+    type = g_boxed_type_register_static ("GstData",
+					 (GBoxedCopyFunc) gst_data_copy,
+					 (GBoxedFreeFunc) gst_data_unref);
+    return type;
+}
+
 /**
  * gst_data_init:
  * @data: a #GstData to initialize
@@ -156,23 +168,6 @@ gst_data_copy_on_write (GstData *data)
   return NULL;
 }
 
-/**
- * gst_data_free:
- * @data: a #GstData to free
- *
- * Frees the given #GstData. This function will call the custom free function
- * provided by the subclass. 
- */
-void
-gst_data_free (GstData *data) 
-{
-  if (!data)
-    return;
-
-  if (data->free)
-    data->free (data); 
-}
-
 /**
  * gst_data_ref:
  * @data: a #GstData to reference
@@ -187,6 +182,9 @@ gst_data_ref (GstData *data)
   g_return_val_if_fail (data != NULL, NULL);
   g_return_val_if_fail (GST_DATA_REFCOUNT_VALUE(data) > 0, NULL);
 
+  GST_CAT_LOG (GST_CAT_BUFFER, "%p %d->%d", data,
+               GST_DATA_REFCOUNT_VALUE (data), GST_DATA_REFCOUNT_VALUE (data) + 1);
+  
   gst_atomic_int_inc (&data->refcount);
 
   return data;
@@ -208,6 +206,9 @@ gst_data_ref_by_count (GstData *data, gint count)
   g_return_val_if_fail (count >= 0, NULL);
   g_return_val_if_fail (GST_DATA_REFCOUNT_VALUE(data) > 0, NULL);
 
+  GST_CAT_LOG (GST_CAT_BUFFER, "%p %d->%d", data,
+               GST_DATA_REFCOUNT_VALUE (data), GST_DATA_REFCOUNT_VALUE (data) + count);
+
   gst_atomic_int_add (&data->refcount, count);
 
   return data;
@@ -231,8 +232,8 @@ gst_data_unref (GstData *data)
 
   g_return_if_fail (data != NULL);
 
-  GST_CAT_LOG (GST_CAT_BUFFER, "unref data %p, count before unref is %d", 
-               data, GST_DATA_REFCOUNT_VALUE (data));
+  GST_CAT_LOG (GST_CAT_BUFFER, "%p %d->%d", data,
+               GST_DATA_REFCOUNT_VALUE (data), GST_DATA_REFCOUNT_VALUE (data) - 1);
   g_return_if_fail (GST_DATA_REFCOUNT_VALUE (data) > 0);
 
   zero = gst_atomic_int_dec_and_test (&data->refcount);
