@@ -21,6 +21,7 @@
 
 #include "dparammanager.h"
 #include <gst/gstelement.h>
+#include <gst/gstmarshal.h>
 #include <gst/gstinfo.h>
 
 GST_DEBUG_CATEGORY_EXTERN(_gst_control_debug);
@@ -111,11 +112,10 @@ gst_dpman_class_init (GstDParamManagerClass *klass)
 
 
 	gst_dpman_signals[NEW_REQUIRED_DPARAM] =
-		g_signal_new ("new_required_dparam", G_TYPE_FROM_CLASS(klass), G_SIGNAL_RUN_LAST,
+		g_signal_new ("new-required-dparam", G_TYPE_FROM_CLASS(klass), G_SIGNAL_RUN_LAST,
 		              G_STRUCT_OFFSET (GstDParamManagerClass, new_required_dparam), NULL, NULL,
 		              gst_marshal_VOID__STRING, G_TYPE_NONE, 1,
 		              G_TYPE_STRING);
-		                              
 }
 
 static void
@@ -313,8 +313,9 @@ gst_dpman_attach_dparam (GstDParamManager *dpman, gchar *dparam_name, GstDParam
 
 	dpwrap = gst_dpman_get_wrapper(dpman, dparam_name);
 
-	g_return_val_if_fail(dpwrap != NULL, FALSE);
-	g_return_val_if_fail(dpwrap->value != NULL, FALSE);
+	g_return_val_if_fail (dpwrap != NULL, FALSE);
+	g_return_val_if_fail (dpwrap->value != NULL, FALSE);
+	g_return_val_if_fail (G_PARAM_SPEC_VALUE_TYPE (dpwrap->param_spec) == GST_DPARAM_TYPE(dparam), FALSE); 
 
 	dpwrap->dparam = dparam;
 	gst_dparam_attach(dparam, dpman, dpwrap->param_spec, dpwrap->unit_name);
@@ -658,6 +659,9 @@ gst_dpman_inline_direct_update(GValue *value, gpointer data){
 		case G_TYPE_FLOAT:
 			*(gfloat*)data = g_value_get_float(value);
 			break;
+                case G_TYPE_DOUBLE:
+			*(double*)data = g_value_get_double(value);
+			break;
 		default:
 			break;
 	}
