@@ -1,3 +1,26 @@
+/* GStreamer
+ * Copyright (C) 1999,2000 Erik Walthinsen <omega@cse.ogi.edu>
+ *               2000 Wim Taymans <wtay@chello.be>
+ *               2004 Thomas Vander Stichele <thomas@apestaart.org>
+ *
+ * gst-launch.c: tool to launch GStreamer pipelines from the command line
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
@@ -7,7 +30,8 @@
 #include <signal.h>
 #include <unistd.h>
 #include <sys/wait.h>
-#include <locale.h>
+#include <locale.h> /* for LC_ALL */
+#include "gst/gst-i18n-app.h"
 
 #include <gst/gst.h>
 
@@ -38,10 +62,6 @@ idle_func (gpointer data)
   GTimeVal tfthen, tfnow;
   GstClockTimeDiff diff;
 
-  if (s_clock) {
-    //g_print ("%" G_GINT64_FORMAT "\n", gst_clock_get_time (s_clock));
-  }
-
   g_get_current_time (&tfthen);
   busy = gst_bin_iterate (GST_BIN (data));
   iterations++;
@@ -56,7 +76,7 @@ idle_func (gpointer data)
 
   if (!busy || caught_intr || (max_iterations>0 && iterations>=max_iterations)) {
     gst_main_quit ();
-    g_print ("execution ended after %" G_GUINT64_FORMAT " iterations (sum %" G_GUINT64_FORMAT " ns, average %" G_GUINT64_FORMAT " ns, min %" G_GUINT64_FORMAT " ns, max %" G_GUINT64_FORMAT " ns)\n", 
+    g_print (_("Execution ended after %" G_GUINT64_FORMAT " iterations (sum %" G_GUINT64_FORMAT " ns, average %" G_GUINT64_FORMAT " ns, min %" G_GUINT64_FORMAT " ns, max %" G_GUINT64_FORMAT " ns).\n"),
 		    iterations, sum, sum/iterations, min, max);
   }
 
@@ -65,7 +85,7 @@ idle_func (gpointer data)
 
 #ifndef GST_DISABLE_LOADSAVE
 static GstElement*
-xmllaunch_parse_cmdline (const gchar **argv) 
+xmllaunch_parse_cmdline (const gchar **argv)
 {
   GstElement *pipeline = NULL, *e;
   GstXML *xml;
@@ -76,7 +96,7 @@ xmllaunch_parse_cmdline (const gchar **argv)
   gint i = 0;
   
   if (!(arg = argv[0])) {
-    g_print ("usage: gst-xmllaunch <file.xml> [ element.property=value ... ]\n");
+    g_print (_("Usage: gst-xmllaunch <file.xml> [ element.property=value ... ]\n"));
     exit (1);
   }
   
@@ -84,18 +104,18 @@ xmllaunch_parse_cmdline (const gchar **argv)
   err = gst_xml_parse_file(xml, arg, NULL);
   
   if (err != TRUE) {
-    fprintf (stderr, "ERROR: parse of xml file '%s' failed\n", arg);
+    fprintf (stderr, _("ERROR: parse of xml file '%s' failed.\n"), arg);
     exit (1);
   }
   
   l = gst_xml_get_topelements (xml);
   if (!l) {
-    fprintf (stderr, "ERROR: no toplevel pipeline element in file '%s'\n", arg);
+    fprintf (stderr, _("ERROR: no toplevel pipeline element in file '%s'.\n"), arg);
     exit (1);
   }
     
   if (l->next)
-    g_warning ("only one toplevel element is supported at this time");
+    fprintf (stderr,  _("WARNING: only one toplevel element is supported at this time."));
   
   pipeline = GST_ELEMENT (l->data);
   
@@ -105,7 +125,7 @@ xmllaunch_parse_cmdline (const gchar **argv)
     value = strchr (element, '=');
     
     if (!(element < property && property < value)) {
-      fprintf (stderr, "ERROR: could not parse command line argument %d: %s", i, element);
+      fprintf (stderr, _("ERROR: could not parse command line argument %d: %s.\n"), i, element);
       g_free (element);
       exit (1);
     }
@@ -115,7 +135,7 @@ xmllaunch_parse_cmdline (const gchar **argv)
     
     e = gst_bin_get_by_name (GST_BIN (pipeline), element);
     if (!e) {
-      g_warning ("element named '%s' not found", element);
+      fprintf (stderr, _("WARNING: element named '%s' not found.\n"), element);
     } else {
       gst_util_set_object_arg (G_OBJECT (e), property, value);
     }
@@ -221,12 +241,46 @@ fault_setup (void)
   sigaction (SIGQUIT, &action, NULL);
 }
 
+static void
+print_tag (const GstTagList *list, const gchar *tag, gpointer unused)
+{
+  gint i, count;
+
+  count = gst_tag_list_get_tag_size (list, tag);
+
+  for (i = 0; i < count; i++) {
+    gchar *str;
+    
+    if (gst_tag_get_type (tag) == G_TYPE_STRING) {
+      g_assert (gst_tag_list_get_string_index (list, tag, i, &str));
+    } else {
+      str = g_strdup_value_contents (
+	      gst_tag_list_get_value_index (list, tag, i));
+    }
+  
+    if (i == 0) {
+      g_print ("%15s: %s\n", gst_tag_get_nick (tag), str);
+    } else {
+      g_print ("               : %s\n", str);
+    }
+
+    g_free (str);
+  }
+}
+static void
+found_tag (GObject *pipeline, GstElement *source, GstTagList *tags)
+{
+  g_print (_("FOUND TAG      : found by element \"%s\".\n"),
+           GST_STR_NULL (GST_ELEMENT_NAME (source)));
+  gst_tag_list_foreach (tags, print_tag, NULL);
+}
+
 /* we only use sighandler here because the registers are not important */
-static void 
+static void
 sigint_handler_sighandler (int signum)
 {
-  g_print ("Caught interrupt\n");
-  
+  g_print ("Caught interrupt.\n");
+
   sigint_restore();
 
   caught_intr = TRUE;
@@ -259,11 +313,11 @@ play_handler (int signum)
 {
   switch (signum) {
     case SIGUSR1:
-      g_print ("Caught SIGUSR1 - Play request\n");
+      g_print ("Caught SIGUSR1 - Play request.\n");
       gst_element_set_state (pipeline, GST_STATE_PLAYING);
       break;
     case SIGUSR2:
-      g_print ("Caught SIGUSR2 - Stop request\n");
+      g_print ("Caught SIGUSR2 - Stop request.\n");
       gst_element_set_state (pipeline, GST_STATE_NULL);
       break;
   }
@@ -286,25 +340,28 @@ main(int argc, char *argv[])
   gint i, j;
   /* options */
   gboolean verbose = FALSE;
+  gboolean tags = FALSE;
   gboolean no_fault = FALSE;
   gboolean trace = FALSE;
   gchar *savefile = NULL;
   gchar *exclude_args = NULL;
   struct poptOption options[] = {
+    {"tags",	't',  POPT_ARG_NONE|POPT_ARGFLAG_STRIP,   &tags,   0,
+     N_("Output tags (also known as metadata)"), NULL},
     {"verbose",	'v',  POPT_ARG_NONE|POPT_ARGFLAG_STRIP,   &verbose,   0,
-     "output status information and property notifications", NULL},
+     N_("Output status information and property notifications"), NULL},
     {"exclude", 'X',  POPT_ARG_STRING|POPT_ARGFLAG_STRIP, &exclude_args,  0,
-     "do not output status information of TYPE", "TYPE1,TYPE2,..."},
+     N_("Do not output status information of TYPE"), N_("TYPE1,TYPE2,...")},
 #ifndef GST_DISABLE_LOADSAVE
     {"output",	'o',  POPT_ARG_STRING|POPT_ARGFLAG_STRIP, &savefile, 0,
-     "save xml representation of pipeline to FILE and exit", "FILE"},
+     N_("Save xml representation of pipeline to FILE and exit"), N_("FILE")},
 #endif
     {"no-fault", 'f', POPT_ARG_NONE|POPT_ARGFLAG_STRIP,   &no_fault,   0,
-     "Do not install a fault handler", NULL},
-    {"trace",   't',  POPT_ARG_NONE|POPT_ARGFLAG_STRIP,   &trace,   0,
-     "print alloc trace if enabled at compile time", NULL},
+     N_("Do not install a fault handler"), NULL},
+    {"trace",   'T',  POPT_ARG_NONE|POPT_ARGFLAG_STRIP,   &trace,   0,
+     N_("Print alloc trace (if enabled at compile time)"), NULL},
     {"iterations",'i',POPT_ARG_INT|POPT_ARGFLAG_STRIP,    &max_iterations,   0,
-     "number of times to iterate pipeline", NULL},
+     N_("Number of times to iterate pipeline"), NULL},
     POPT_TABLEEND
   };
 
@@ -314,10 +371,12 @@ main(int argc, char *argv[])
 
   free (malloc (8)); /* -lefence */
 
-  setlocale(LC_ALL, "");
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
 
   gst_alloc_trace_set_flags_all (GST_ALLOC_TRACE_LIVE);
-  
+
   gst_init_with_popt_table (&argc, &argv, options);
 
   /* FIXpopt: strip short args, too. We do it ourselves for now */
@@ -346,7 +405,7 @@ main(int argc, char *argv[])
   
   if (trace) {
     if (!gst_alloc_trace_available()) {
-      g_warning ("trace not available (recompile with trace enabled)");
+      g_warning ("Trace not available (recompile with trace enabled).");
     }
     gst_alloc_trace_print_all ();
   }
@@ -367,14 +426,16 @@ main(int argc, char *argv[])
 
   if (!pipeline) {
     if (error) {
-      fprintf(stderr, "ERROR: pipeline could not be constructed: %s\n", error->message);
+      fprintf(stderr, _("ERROR: pipeline could not be constructed: %s.\n"),
+              error->message);
       g_error_free (error);
     } else {
-      fprintf(stderr, "ERROR: pipeline could not be constructed\n");
+      fprintf(stderr, _("ERROR: pipeline could not be constructed.\n"));
     }
     exit(1);
   } else if (error) {
-    fprintf(stderr, "WARNING: erroneous pipeline: %s\n         Trying to run anyway\n", error->message);
+    fprintf(stderr, _("WARNING: erroneous pipeline: %s\n"), error->message);
+    fprintf(stderr, _("         Trying to run anyway.\n"));
     g_error_free (error);
   }
   
@@ -382,6 +443,9 @@ main(int argc, char *argv[])
     gchar **exclude_list = exclude_args ? g_strsplit (exclude_args, ",", 0) : NULL;
     g_signal_connect (pipeline, "deep_notify", G_CALLBACK (gst_element_default_deep_notify), exclude_list);
   }
+  if (tags) {
+    g_signal_connect (pipeline, "found-tag", G_CALLBACK (found_tag), NULL);
+  }
   g_signal_connect (pipeline, "error", G_CALLBACK (gst_element_default_error), NULL);
   
 #ifndef GST_DISABLE_LOADSAVE
@@ -395,16 +459,16 @@ main(int argc, char *argv[])
     if (!GST_IS_BIN (pipeline)) {
       GstElement *real_pipeline = gst_element_factory_make ("pipeline", NULL);
       if (real_pipeline == NULL) {
-        fprintf(stderr, "ERROR: The pipeline element wasn't found.\n");
+        fprintf(stderr, _("ERROR: the 'pipeline' element wasn't found.\n"));
         exit(1);
       }
       gst_bin_add (GST_BIN (real_pipeline), pipeline);
       pipeline = real_pipeline;
     }
 
-    fprintf(stderr,"RUNNING pipeline\n");
+    fprintf(stderr, _("RUNNING pipeline ...\n"));
     if (gst_element_set_state (pipeline, GST_STATE_PLAYING) == GST_STATE_FAILURE) {
-      fprintf(stderr,"pipeline doesn't want to play\n");
+      fprintf(stderr, _("ERROR: pipeline doesn't want to play.\n"));
       res = -1;
       goto end;
     }
@@ -415,9 +479,9 @@ main(int argc, char *argv[])
         g_idle_add (idle_func, pipeline);
         gst_main ();
     } else {
-        g_print ("waiting for the state change...\n");
+        g_print ("Waiting for the state change... ");
         gst_element_wait_state_change (pipeline);
-        g_print ("got the state change...\n");
+        g_print ("got the state change.\n");
     }
 
     gst_element_set_state (pipeline, GST_STATE_NULL);
