@@ -1,6 +1,11 @@
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
+
 #include <string.h>
 #include <stdlib.h>
 #include <gst/gst.h>
+#include <locale.h>
 
 static guint64 iterations = 0;
 static guint64 sum = 0;
@@ -62,6 +67,8 @@ main (int argc, char *argv[])
 
   free (malloc (8)); /* -lefence */
 
+  setlocale (LC_ALL, "");
+
   gst_init_with_popt_table (&argc, &argv, options);
 
   /* make a parseable argvn array */
